==> zio-aws-cloudfront_2.13-5.17.104.1-sources.jar: zio/aws/cloudfront/model/FunctionList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class FunctionList(
    nextMarker: Option[String] = None,
    maxItems: Integer,
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.FunctionSummary]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.FunctionList = {
    import FunctionList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.FunctionList
      .builder()
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(Integer.unwrap(maxItems): java.lang.Integer)
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.FunctionList.ReadOnly =
    zio.aws.cloudfront.model.FunctionList.wrap(buildAwsValue())
}
object FunctionList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.FunctionList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.FunctionList =
      zio.aws.cloudfront.model.FunctionList(
        nextMarker.map(value => value),
        maxItems,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Option[String]
    def maxItems: Integer
    def quantity: Integer
    def items: Option[List[zio.aws.cloudfront.model.FunctionSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.FunctionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionList
  ) extends zio.aws.cloudfront.model.FunctionList.ReadOnly {
    override val nextMarker: Option[String] =
      scala.Option(impl.nextMarker()).map(value => value: String)
    override val maxItems: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.maxItems())
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items
        : Option[List[zio.aws.cloudfront.model.FunctionSummary.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.FunctionSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionList
  ): zio.aws.cloudfront.model.FunctionList.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.157.1-sources.jar: zio/aws/cloudfront/model/FunctionList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class FunctionList(
    nextMarker: Option[String] = None,
    maxItems: Integer,
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.FunctionSummary]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.FunctionList = {
    import FunctionList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.FunctionList
      .builder()
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(maxItems: java.lang.Integer)
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.FunctionList.ReadOnly =
    zio.aws.cloudfront.model.FunctionList.wrap(buildAwsValue())
}
object FunctionList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.FunctionList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.FunctionList =
      zio.aws.cloudfront.model.FunctionList(
        nextMarker.map(value => value),
        maxItems,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextMarker: Option[String]
    def maxItems: Integer
    def quantity: Integer
    def items: Option[List[zio.aws.cloudfront.model.FunctionSummary.ReadOnly]]
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.FunctionSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionList
  ) extends zio.aws.cloudfront.model.FunctionList.ReadOnly {
    override val nextMarker: Option[String] =
      scala.Option(impl.nextMarker()).map(value => value: String)
    override val maxItems: Integer = impl.maxItems(): Integer
    override val quantity: Integer = impl.quantity(): Integer
    override val items
        : Option[List[zio.aws.cloudfront.model.FunctionSummary.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.FunctionSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.FunctionList
  ): zio.aws.cloudfront.model.FunctionList.ReadOnly = new Wrapper(impl)
}
